@@ -23,12 +23,12 @@ import os.path
 import time
 import unittest
 import re
-import sys
 import tempfile
+from os.path import splitext
+from os import mkdir, rmdir, remove
 
 from stratuslab.Monitor import Monitor
 from stratuslab.Registrar import Registrar
-from stratuslab.Runner import Runner
 from stratuslab.marketplace.Uploader import Uploader as marketplaceUploader
 from stratuslab.Creator import Creator
 from stratuslab.Exceptions import OneException, ClientException
@@ -42,23 +42,24 @@ from stratuslab.marketplace.ManifestDownloader import ManifestDownloader
 import stratuslab.ClusterTest as ClusterTest
 import stratuslab.RegistrationTest as RegistrationTest
 import stratuslab.LdapAuthenticationTest as LdapAuthenticationTest
-from stratuslab.PersistentDisk import PersistentDisk
-from stratuslab.Util import sleep, printStep, filePutContent
+from stratuslab.volume_manager.volume_manager_factory import VolumeManagerFactory
+from stratuslab.vm_manager.vm_manager_factory import VmManagerFactory
+from stratuslab.Util import sleep, filePutContent
+from stratuslab.Util import printStep, printInfo, printWarning
 from stratuslab.image.Image import Image
 from stratuslab.ManifestInfo import ManifestInfo
-from os.path import splitext
-from os import mkdir, rmdir, remove
 
-VM_START_TIMEOUT = 5 * 60 # 5 min
+
+VM_START_TIMEOUT = 5 * 60  # 5 min
+
 
 class Testor(unittest.TestCase):
-
     configHolder = None
     testNames = []
 
     def setUp(self):
         self.vmIds = []
-        self.image = 'BN1EEkPiBx87_uLj2-sdybSI-Xb' # ttylinux v14 x86_64
+        self.image = 'BN1EEkPiBx87_uLj2-sdybSI-Xb'  # ttylinux v14 x86_64
         self.ubuntuImg = 'BXSSv_2udGkpKgi6fcCaVniz1Zd'
         self._unlinkFiles([self.sshKey, self.sshKeyPub])
 
@@ -69,7 +70,8 @@ class Testor(unittest.TestCase):
         for f in filesList:
             try:
                 os.unlink(f)
-            except: pass
+            except:
+                pass
 
     def __init__(self, methodName='dummy'):
         super(Testor, self).__init__(methodName)
@@ -100,7 +102,8 @@ class Testor(unittest.TestCase):
         if Util.envEndpoint in os.environ:
             return
         if not self.frontendIp:
-            raise ConfigurationException('Missing environment variable %s or configuration parameter frontend_ip' % Util.envEndpoint)
+            raise ConfigurationException(
+                'Missing environment variable %s or configuration parameter frontend_ip' % Util.envEndpoint)
         os.environ[Util.envEndpoint] = self.frontendIp
 
     def dummy(self):
@@ -108,7 +111,6 @@ class Testor(unittest.TestCase):
 
     def runTests(self):
         suite = unittest.TestSuite()
-        tests = []
         if self.testNames:
             tests = self.testNames
         else:
@@ -126,16 +128,16 @@ class Testor(unittest.TestCase):
         return method()
 
     def runInstancePublicNetworkTest(self):
-        '''Start new instance, ping it via public network and ssh into it, then stop it.'''
+        """Start new instance, ping it via public network and ssh into it, then stop it."""
         self._runInstanceTest()
 
     def runInstanceLocalNetworkTest(self):
-        '''Start new instance, ping it via local network and ssh into it, then stop it.'''
+        """Start new instance, ping it via local network and ssh into it, then stop it."""
         self._runInstanceTest(withLocalNetwork=True,
-                                cmdToRun=['ping -c 2 www.google.com'])
+                              cmdToRun=['ping -c 2 www.google.com'])
 
     def runInstanceRequestedNetworkTest(self):
-        '''Start new instance, ping it via requested IP address and ssh into it, then stop it.'''
+        """Start new instance, ping it via requested IP address and ssh into it, then stop it."""
 
         self._checkAttributePresent(['requestedIpAddress'])
         if not self.requestedIpAddress:
@@ -151,26 +153,26 @@ class Testor(unittest.TestCase):
         self._stopVm(runner)
 
     def exceedCpuQuotaTest(self):
-        '''Start x instances, where x is the cpu quota +1, then stop them.'''
+        """Start x instances, where x is the cpu quota +1, then stop them."""
 
-        print 'Current cpu quota: %s, starting as many +1' % self.quotaCpu
+        printInfo('Current cpu quota: %s, starting as many +1' % self.quotaCpu)
         try:
             self._startVm(instanceNumber=int(self.quotaCpu) + 1)
         except OneException, ex:
             message = "CPU quota exceeded (Quota: %s.0, Used: %s.0, Requested: 1.0)." % (self.quotaCpu, self.quotaCpu)
-            self.assertTrue(message in ex.message, 'Quota not working, got %s expected %s' % (ex.message, message))
+            self.assertTrue(message in str(ex), 'Quota not working, got %s expected %s' % (ex.message, message))
         else:
             self.fail('Quota not enforced')
         finally:
             self._createRunner().killInstances(self.runner.vmIds)
-        
+
     def _excludeTests(self, tests):
         if self.testsToExclude:
             for test in self.testsToExclude.split(','):
                 try:
                     tests.remove(test)
                 except ValueError:
-                    print "WARNING: Test '%s' not in a list of defined tests." % test
+                    printWarning("WARNING: Test '%s' not in a list of defined tests." % test)
 
     def _runInstanceTest(self, withLocalNetwork=False, cmdToRun=['/bin/true'], msgRecipients=None):
         runner = self._startVm(withLocalNetwork=withLocalNetwork, msgRecipients=msgRecipients)
@@ -186,7 +188,7 @@ class Testor(unittest.TestCase):
         log.write('=' * 60 + '\n' * 3)
         return log
 
-    def _startVm(self, withLocalNetwork=False, requestedIpAddress=None, 
+    def _startVm(self, withLocalNetwork=False, requestedIpAddress=None,
                  instanceNumber=1, noCheckImageUrl=False, msgRecipients=None,
                  raiseOnFailed=True):
         self.runner = self._createRunner(withLocalNetwork, requestedIpAddress)
@@ -200,24 +202,24 @@ class Testor(unittest.TestCase):
         vmIds = self.runner.runInstance()
         self.vmIds.extend(vmIds)
 
-        for id in vmIds:
-            vmStarted = self.runner.waitUntilVmRunningOrTimeout(id, VM_START_TIMEOUT,
-                                                                failOn=('Failed'))
+        for vmId in vmIds:
+            vmStarted = self.runner.waitUntilVmRunningOrTimeout(vmId, VM_START_TIMEOUT,
+                                                                failOn='Failed')
             if not vmStarted and raiseOnFailed:
-                error = 'Failed to start VM id: %s' % id
+                error = 'Failed to start VM id: %s' % vmId
                 Util.printError(error, exit=False)
                 raise OneException(error)
 
         return self.runner
 
-    def _createRunner(self, withLocalNetwork=False, requestedIpAddress=None, 
+    def _createRunner(self, withLocalNetwork=False, requestedIpAddress=None,
                       persistentDiskUUID=None, image=None):
         Util.generateSshKeyPair(self.sshKey)
 
         if not image:
             image = self.image
 
-        options = Runner.defaultRunOptions()
+        options = VmManagerInstance.defaultRunOptions()
         options['username'] = self.testUsername
         options['password'] = self.testPassword
         options['userPublicKeyFile'] = self.sshKeyPub
@@ -231,7 +233,7 @@ class Testor(unittest.TestCase):
             options['isLocalIp'] = True
 
         configHolder = ConfigHolder(options)
-        return Runner(image, configHolder)
+        return VmManagerFactory.create(image, configHolder)
 
     def _repeatCall(self, method, *args):
         numberOfRepetition = 60
@@ -286,13 +288,13 @@ class Testor(unittest.TestCase):
                 raise Exception('Attribute %s is not set. Missing an option argument?' % attr)
 
     def _generateDummyImage(self, filename, size=2):
-        devNull = open('/dev/null', 'w')
+        devNull = open(os.path.devnull, 'w')
         Util.execute(['dd', 'if=/dev/zero', 'of=%s' % filename, 'bs=1000000', 'count=%s' % size],
-        stdout=devNull, stderr=devNull)
+                     stdout=devNull, stderr=devNull)
         devNull.close()
 
     def registrarTest(self):
-        '''Register a new node with ONE server, check that it is properly registered and remove it'''
+        """Register a new node with ONE server, check that it is properly registered and remove it"""
         configHolder = self.configHolder.copy()
         configHolder.options['infoDriver'] = 'kvm'
         configHolder.options['virtDriver'] = 'kvm'
@@ -302,43 +304,19 @@ class Testor(unittest.TestCase):
         configHolder.options['password'] = self.proxyOneadminPassword
         registrar = Registrar(configHolder)
         hostname = 'registrar.ip.test'
-        id = registrar.register([hostname])
+        vmId = registrar.register([hostname])
         monitor = Monitor(configHolder)
-        info = monitor.nodeDetail([id])[0]
+        info = monitor.nodeDetail([vmId])[0]
         self.assertEqual(hostname, info.name)
         registrar.deregister(hostname)
-        self.assertRaises(Exception, monitor.nodeDetail, [id])
+        self.assertRaises(Exception, monitor.nodeDetail, [vmId])
 
 
-    def notificationTest(self):
-        '''Check notifications on VM state changes'''
-        pass
-
-        #notifier = NotificationUseCaseTest()
-
-        #connection = None
-        #channel = None
-
-        #try:
-
-        #    connection, channel = notifier.initializeMessageQueue()
-
-        #    msgRecipients = notifier.createMsgRecipients()
-
-        #    self._runInstanceTest(msgRecipients=msgRecipients)
-
-        #    vmId = self.vmIds[0]
-
-        #    notifier.checkNotificationMessages(connection, vmId)
-
-        #finally:                
-        #    notifier.cleanUpMessageQueue(connection)
-
-
-    def listAvalableTests(self):
-        print 'Available tests:'
+    def formatAvailableTests(self):
+        result = "Available tests:\n"
         for testName, testDoc in self._extractTestDescriptions():
-            print '    - %s: %s' % (testName, testDoc)
+            result += "    - %s: %s\n" % (testName, testDoc)
+        return result
 
     def _extractTestDescriptions(self):
         methods = []
@@ -360,18 +338,17 @@ class Testor(unittest.TestCase):
                not attrib.startswith('_')
 
     def createImageTest(self):
-        '''Create a machine image based on a given one.'''
+        """Create a machine image based on a given one."""
 
         self._checkAttributePresentAndInitialized(['imageIdCreateImage',
                                                    'authorEmailCreateImage'])
         self._doCreateImage()
 
     def _doCreateImage(self):
-
         remote_test_file = '$HOME/createImageTest-%s' % str(os.getpid())
         script = """#!/bin/sh
-touch %s
-""" % remote_test_file
+    touch %s
+    """ % remote_test_file
 
         fd, script_file = tempfile.mkstemp('.sh', 'script')
         os.write(fd, script)
@@ -393,15 +370,13 @@ touch %s
 
         timeout = 1000
         t_stop = time.time() + timeout
-        t_step  = 10
-        print "Waiting %i sec for image bundling. One dot %i sec." % (timeout,
-                                                                      t_step)
+        t_step = 10
+        printInfo("Waiting %i sec for image bundling." % timeout)
+
         while time.time() < t_stop:
             if creator.getVmState() in ('Done', 'Failed'):
-                print
                 break
-            sys.stdout.write('.')
-            sys.stdout.flush()
+            printInfo('Time remaining: %d' % (t_stop - time.time()))
             time.sleep(t_step)
 
         # Assert instance state
@@ -414,11 +389,11 @@ touch %s
             info = monitor._vmDetail(creator.getVmId())
             info_attributes = info.getAttributes()
             msg = "Image creation failed. Instance final state '%s'. Error: %s" % \
-                        (vm_state, info_attributes.get('template_error_message',
-                                                       'not set'))
+                  (vm_state, info_attributes.get('template_error_message',
+                                                 'not set'))
             self.fail(msg)
-        
-        # Assert new image. 
+
+        # Assert new image.
         # Assuming we are running on FE and can access VM log file.
         vm_id = creator.getVmId()
         mp_and_id = ''
@@ -431,7 +406,7 @@ touch %s
             self.fail("Failed to obtain new image ID.")
         marketplace_url = mp_and_id[-2].strip('\'')
         if not Util.isValidNetLocation(marketplace_url):
-            self.fail("Failed to get marketplace endpoint.") 
+            self.fail("Failed to get marketplace endpoint.")
 
         self.configHolder.marketplaceEndpoint = marketplace_url
         ManifestDownloader(self.configHolder).getManifestInfo(image_id)
@@ -446,7 +421,6 @@ touch %s
         self._runInstanceTest(cmdToRun=cmds)
 
     def _createCreator(self, image, script_file=''):
-
         Util.generateSshKeyPair(self.sshKey)
         options = {}
 
@@ -454,9 +428,9 @@ touch %s
 
         options['authorEmail'] = self.authorEmailCreateImage
         options['saveDisk'] = True
-    
+
         options['instanceType'] = 'c1.medium'
-    
+
         options['verboseLevel'] = self.verboseLevel
 
         options['author'] = 'Jane Tester'
@@ -484,20 +458,20 @@ touch %s
         options['shutdownVm'] = True
 
         options['marketplaceEndpoint'] = Downloader.ENDPOINT
-        
+
         configHolder = ConfigHolder(options)
 
         return Creator(image, configHolder)
 
     def _registerInvalidImageInMarketplace(self):
-        manifest_file = os.path.join(Util.getResourcesDir(), 
+        manifest_file = os.path.join(Util.getResourcesDir(),
                                      'manifest-invalid-sha1.xml')
-        
+
         manifestInfo = ManifestInfo()
         manifestInfo.parseManifestFromFile(manifest_file)
-        
+
         image_id = manifestInfo.identifier
-        
+
         configHolder = ConfigHolder()
         configHolder.set('marketplaceEndpoint', self.marketplaceEndpoint)
         uploader = marketplaceUploader(configHolder)
@@ -510,7 +484,7 @@ touch %s
         self.marketplaceEndpoint = self.marketplaceEndpointUpload or mpendp_save
 
         try:
-            self.image = self._registerInvalidImageInMarketplace()    
+            self.image = self._registerInvalidImageInMarketplace()
             info, vmId = self._startStopVmAndGetVmInfo()
         finally:
             self.marketplaceEndpoint = mpendp_save
@@ -518,7 +492,7 @@ touch %s
         return info, vmId
 
     def oneReportsErrorViaXmlRpcTest(self):
-        '''Test if ONE reports error messages via XML RPC'''
+        """Test if ONE reports error messages via XML RPC"""
 
         info, vmId = self._startStopInvalidImage()
 
@@ -528,11 +502,11 @@ touch %s
             self.fail("No error message set.")
         else:
             self.failUnless(errorMessage, "Empty error message.")
-            print 'VM %s failed with error message:\n%s' % (vmId, errorMessage)
+            printInfo('VM %s failed with error message:\n%s' % (vmId, errorMessage))
 
     def _startStopVmAndGetVmInfo(self):
-        'Return VM monitoring info and VM id.'
-        
+        """Return VM monitoring info and VM id."""
+
         self._startVm(noCheckImageUrl=True, raiseOnFailed=False)
         vmId = self.runner.vmIds[0]
         self._stopVm(self.runner)
@@ -548,256 +522,265 @@ touch %s
         return info, vmId
 
     def marketPlaceTest(self):
-        '''Place holder for marketplace test'''
+        """Placeholder for marketplace test"""
         pass
-    
+
     def clusterTest(self):
-        '''Cluster test'''
+        """Cluster test"""
         ClusterTest.ClusterTest.sshKeyPub = self.sshKeyPub
         ClusterTest.ClusterTest.username = self.testUsername
         ClusterTest.ClusterTest.password = self.testPassword
         suite = self._createSuiteFromTestModule(ClusterTest)
         self._executeSuite(suite)
-  
+
     def registrationTest(self):
-        '''Registration test'''
+        """Registration test"""
         suite = self._createSuiteFromTestModule(RegistrationTest)
         self._executeSuite(suite)
-  
+
     def ldapAuthenticationTest(self):
-        '''LDAP authentication test'''
+        """LDAP authentication test"""
         suite = self._createSuiteFromTestModule(LdapAuthenticationTest)
         self._executeSuite(suite)
-  
+
     def _createSuiteFromTestModule(self, module):
         suite = unittest.TestSuite()
         tests = unittest.TestLoader().loadTestsFromModule(module)
         suite.addTests(tests)
         return suite
-        
+
     def _executeSuite(self, suite):
         testResult = unittest.TextTestRunner(verbosity=2).run(suite)
         self.assertTrue(testResult.wasSuccessful())
-        
+
     def persistentDiskStorageTest(self):
-        '''Ensure that a disk can be created, written, stored and removed'''
-        
-        pdiskDevice = '/dev/hdc' # !!!! Configured for the default image (ttylinux)
+        """Ensure that a disk can be created, written, stored and removed"""
+
+        pdiskDevice = '/dev/hdc'  # !!!! Configured for the default image (ttylinux)
         pdiskMountPoint = '/mnt/pdisk-test'
         testFile = '%s/pdisk.txt' % pdiskMountPoint
         testFileCmp = '/tmp/pdisk.cmp'
         testString = 'pdiskTest'
-        
+
         configHolder = Testor.configHolder.copy()
         configHolder.pdiskUsername = Testor.configHolder.testUsername
         configHolder.pdiskPassword = Testor.configHolder.testPassword
-        pdisk = PersistentDisk(configHolder)
-        
+        pdisk = VolumeManagerFactory.create(configHolder)
+
         Util.printAction('Creating a new persistent disk')
         diskUUID = pdisk.createVolume(1, 'test %s' % datetime.datetime.today(), False)
-        
+
         Util.printAction('Checking persistent disk exists')
         if not pdisk.volumeExists(diskUUID):
             self.fail('An error occurred while creating a persistent disk')
-            
+
         Util.printAction('Getting number of available users (before)')
         availableUserBeforeStart, _ = pdisk.getVolumeUsers(diskUUID)
         Util.printAction('Starting machine with persistent disk')
         runner = self._startVmWithPDiskAndWaitUntilUp(diskUUID)
         Util.printAction('Getting number of available users (after)')
         availableUserAfterStart, _ = pdisk.getVolumeUsers(diskUUID)
-        
-        if availableUserAfterStart != (availableUserBeforeStart-1):
+
+        if availableUserAfterStart != (availableUserBeforeStart - 1):
             self.fail('Available users on persistent disk have to decrease by '
-                      'one (%s, %s)' % 
+                      'one (%s, %s)' %
                       (availableUserBeforeStart, availableUserAfterStart))
-    
+
         self._formatDisk(runner, pdiskDevice)
         self._mountDisk(runner, pdiskDevice, pdiskMountPoint)
         self._writeToFile(runner, testFile, testString)
         self._umountPDiskAndStopVm(runner, pdiskDevice)
 
+        # Allow a few seconds for the disk to be dismounted.
+        time.sleep(10)
+
         availableUserAfterStop, _ = pdisk.getVolumeUsers(diskUUID)
-        
+
         if availableUserAfterStop != availableUserBeforeStart:
             self.fail('Available users on persistent disk have to be the same '
                       'as when VM has started')
-    
+
         runner = self._startVmWithPDiskAndWaitUntilUp(diskUUID)
         self._mountDisk(runner, pdiskDevice, pdiskMountPoint)
         self._writeToFile(runner, testFileCmp, testString)
         self._compareFiles(runner, testFile, testFileCmp)
-        self._umountPDiskAndStopVm(runner, pdiskDevice)      
-        
+        self._umountPDiskAndStopVm(runner, pdiskDevice)
+
         availableUserAfterStop, _ = pdisk.getVolumeUsers(diskUUID)
-        
+
         if availableUserAfterStop != availableUserBeforeStart:
             self.fail('Available users on persistent disk have to be the same '
                       'as when VM has started')
 
         Util.printAction('Removing persistent disk...')
         pdisk.deleteVolume(diskUUID)
-        
+
         try:
             if pdisk.volumeExists(diskUUID):
                 self.fail('The persistent disk %s is still present' % diskUUID)
         except ClientException, ex:
             if not re.match('404', ex.status):
                 self.fail('The persistent disk %s is still present' % diskUUID)
-            
+
     def persistentDiskStorageHotplugTest(self):
-        '''Ensure that a disk hot-plugged to a VM and then hot-unplugged'''
-        
+        """Ensure that a disk hot-plugged to a VM and then hot-unplugged"""
+
         pdiskDevice = '/dev/%s'
         pdiskMountPoint = '/mnt/pdisk-test'
         testFile = '%s/pdisk.txt' % pdiskMountPoint
         testFileCmp = '/tmp/pdisk.cmp'
         testString = 'pdiskTest'
-        
+
         configHolder = Testor.configHolder.copy()
         configHolder.pdiskUsername = Testor.configHolder.testUsername
         configHolder.pdiskPassword = Testor.configHolder.testPassword
-        pdisk = PersistentDisk(configHolder)
-        
+        pdisk = VolumeManagerFactory.create(configHolder)
+
         runner = self._startVmWithPDiskAndWaitUntilUp(image=self.ubuntuImg)
-        
+
         Util.printAction('Creating a new persistent disk')
         diskUUID = pdisk.createVolume(1, 'test %s' % datetime.datetime.today(),
                                       False)
-        
+
         Util.printAction('Checking persistent disk exists')
         if not pdisk.volumeExists(diskUUID):
             self.fail('An error occurred while creating a persistent disk')
-        
+
         self._modeprobe(runner, 'acpiphp')
         vmId = self.vmIds[0]
         node = runner.cloud.getVmNode(vmId)
-        
+
         printStep('Attaching pdisk to VM')
-        
+
         availableUserBeforeAttach, _ = pdisk.getVolumeUsers(diskUUID)
         device = pdisk.hotAttach(node, vmId, diskUUID)
         availableUserAfterAttach, _ = pdisk.getVolumeUsers(diskUUID)
-        
-        if availableUserAfterAttach != (availableUserBeforeAttach-1):
+
+        if availableUserAfterAttach != (availableUserBeforeAttach - 1):
             self.fail('Available users on persistent disk have to decrease by '
-                      'one; before=%s, after=%s' % 
+                      'one; before=%s, after=%s' %
                       (availableUserBeforeAttach, availableUserAfterAttach))
-        
+
         self._formatDisk(runner, pdiskDevice % device)
         self._mountDisk(runner, pdiskDevice % device, pdiskMountPoint)
         self._writeToFile(runner, testFile, testString)
         self._umountDisk(runner, pdiskDevice % device)
-        
+
         printStep('Detaching pdisk of VM')
         pdisk.hotDetach(node, vmId, diskUUID)
 
         availableUserAfterDetach, _ = pdisk.getVolumeUsers(diskUUID)
-        
+
         if availableUserAfterDetach != availableUserBeforeAttach:
             self.fail('Available users on persistent disk have to be the '
                       'same as when VM has started; before=%s, after=%s' %
                       (availableUserBeforeAttach, availableUserAfterDetach))
-        
+
         printStep('Re-attaching pdisk to VM')
         device = pdisk.hotAttach(node, vmId, diskUUID)
-        
+
         self._mountDisk(runner, pdiskDevice % device, pdiskMountPoint)
         self._writeToFile(runner, testFileCmp, testString)
         self._compareFiles(runner, testFile, testFileCmp)
         self._umountPDiskAndStopVm(runner, pdiskDevice % device)
-        
+
         availableUserAfterStop, _ = pdisk.getVolumeUsers(diskUUID)
-        
+
         if availableUserAfterStop != availableUserBeforeAttach:
             self.fail('Available users on persistent disk have to be the '
-                      'same as when VM has started; before=%s, after=%s' % 
+                      'same as when VM has started; before=%s, after=%s' %
                       (availableUserBeforeAttach, availableUserAfterStop))
 
         Util.printAction('Removing persistent disk...')
         pdisk.deleteVolume(diskUUID)
-            
+
         try:
             if pdisk.volumeExists(diskUUID):
                 self.fail('The persistent disk %s is still present' % diskUUID)
         except ClientException, ex:
             if not re.match('404', ex.status):
                 self.fail('The persistent disk %s is still present' % diskUUID)
-                
+
     def persistentDiskStorageDownloadTest(self):
-        '''Check that an image can be downloaded correctly'''
-        pdiskDevice = '/dev/hdc' # !!!! Configured for the default image (ttylinux)
+        """Check that an image can be downloaded correctly"""
+        pdiskDevice = '/dev/hdc'  # !!!! Configured for the default image (ttylinux)
         pdiskMountPoint = '/mnt/pdisk-test'
         testFile = '%s/pdisk.txt'
         testString = 'pdiskTest'
         downloadedCompressedDisk = '/var/tmp/pdisk-img.gz'
         localMountPoint = '/mnt/pdisk-check'
         localTestFile = '/tmp/pdiskGzip.tmp'
-        
+
         configHolder = Testor.configHolder.copy()
         configHolder.pdiskUsername = Testor.configHolder.testUsername
         configHolder.pdiskPassword = Testor.configHolder.testPassword
-        pdisk = PersistentDisk(configHolder)
-        
+        pdisk = VolumeManagerFactory.create(configHolder)
+
         Util.printAction('Creating a new persistent disk')
         diskUUID = pdisk.createVolume(1, 'test %s' % datetime.datetime.today(), False)
-        
+
         Util.printAction('Checking persistent disk exists')
         if not pdisk.volumeExists(diskUUID):
             self.fail('An error occurred while creating a persistent disk')
-            
+
         Util.printAction('Starting machine with persistent disk')
         runner = self._startVmWithPDiskAndWaitUntilUp(diskUUID)
-        
+
         self._formatDisk(runner, pdiskDevice)
         self._mountDisk(runner, pdiskDevice, pdiskMountPoint)
         self._writeToFile(runner, testFile % pdiskMountPoint, testString)
         self._umountPDiskAndStopVm(runner, pdiskDevice)
-        
+
         try:
             Util.printAction('Downloading volume...')
             # compressed disk comes in HTTP response - don't print it from HTTP client!
-            verb_save = pdisk.configHolder.verboseLevel
-            pdisk.configHolder.verboseLevel = 0
+            verb_save = pdisk.client.verboseLevel
+            pdisk.client.verboseLevel = 0
             pdisk.downloadVolume(diskUUID, downloadedCompressedDisk)
-            pdisk.configHolder.verboseLevel = verb_save
+            pdisk.client.verboseLevel = verb_save
             volume = self._gunzip(downloadedCompressedDisk)
         finally:
-            try: remove(downloadedCompressedDisk)
-            except: pass
+            try:
+                remove(downloadedCompressedDisk)
+            except:
+                pass
 
         try:
-            if not self._localMount(volume, localMountPoint, ['loop',]):
+            if not self._localMount(volume, localMountPoint, ['loop', ]):
                 self.fail('Error mounting downloaded image, corrupted?')
-            
+
             filePutContent(localTestFile, testString)
-            
+
             fileEquals = self._compareLocalFiles(localTestFile, testFile % localMountPoint)
-            
+
             if not fileEquals:
                 self.fail('Downloaded volume is corrupted')
-                
+
             self._localUmount(localMountPoint)
         finally:
             Util.printAction('Post test clean-up...')
-            try: remove(volume)
-            except: pass
-            try: rmdir(localMountPoint)
-            except: pass
+            try:
+                remove(volume)
+            except:
+                pass
+            try:
+                rmdir(localMountPoint)
+            except:
+                pass
 
     def _startVmWithPDiskAndWaitUntilUp(self, pdisk=None, image=None):
         runner = self._createRunner(persistentDiskUUID=pdisk, image=image)
         vmIds = runner.runInstance()
         if len(vmIds) < 1:
             self.fail('An error occurred while starting a VM')
-        if not runner.waitUntilVmRunningOrTimeout(vmIds[0], failOn=('Failed')):
+        if not runner.waitUntilVmRunningOrTimeout(vmIds[0], failOn='Failed'):
             self.fail('Failed starting VM: image %s, pdisk %s' % (str(image or runner.vm_image),
                                                                   str(pdisk)))
         self.vmIds.extend(vmIds)
         self._repeatCall(self._ping, runner)
         self._repeatCall(self._loginViaSsh, runner, '/bin/true')
         return runner
-    
+
     def _umountPDiskAndStopVm(self, runner, pdiskDevice):
         self._umountDisk(runner, pdiskDevice)
         Util.printStep('Stopping VM...')
@@ -805,37 +788,37 @@ touch %s
         self.vmIds = []
         # Wait for the pdisk hook to be executed
         sleep(20)
-    
+
     def _formatDisk(self, runner, device):
         Util.printStep('Formating device %s' % device)
         mkfsScript = '/tmp/mkfs'
-        self._loginViaSsh(runner, 'echo "echo \'y\' | /sbin/mkfs.ext3 %s" > %s' 
-                                    % (device, mkfsScript))
+        self._loginViaSsh(runner, 'echo "echo \'y\' | /sbin/mkfs.ext3 %s" > %s'
+                                  % (device, mkfsScript))
         self._loginViaSsh(runner, 'bash %s' % mkfsScript)
-        
+
     def _mountDisk(self, runner, device, mountPoint):
         Util.printStep('Mounting device %s in %s...' % (device, mountPoint))
         self._loginViaSsh(runner, 'mkdir -p %s' % mountPoint)
         self._loginViaSsh(runner, 'mount %s %s' % (device, mountPoint))
-    
+
     def _localMount(self, device, mountPoint, options=[]):
-        Util.printStep('Mounting device %s on %s with options %s' % (device, mountPoint, 
-                                                                    (', '.join(options) or '<no options>')))
+        Util.printStep('Mounting device %s on %s with options %s' % (device, mountPoint,
+                                                                     (', '.join(options) or '<no options>')))
         mountOptions = ['-o', ','.join(options)]
         try:
             mkdir(mountPoint)
         except:
             pass
-        rc, output = Util.executeGetStatusOutput(['mount'] + mountOptions + [device, mountPoint], 
+        rc, output = Util.executeGetStatusOutput(['mount'] + mountOptions + [device, mountPoint],
                                                  verboseLevel=self.verboseLevel)
         if output:
-            print output
+            printInfo(output)
         return rc == 0 and True or False
-        
+
     def _localUmount(self, device):
         Util.printStep('Unmounting device %s...' % device)
         Util.execute(['umount', device])
-        
+
     def _umountDisk(self, runner, device):
         Util.printStep('Unmounting device %s...' % device)
         self._loginViaSsh(runner, 'umount %s' % device)
@@ -843,19 +826,19 @@ touch %s
     def _writeToFile(self, runner, filename, what):
         Util.printStep('Writing content to %s...' % filename)
         self._loginViaSsh(runner, 'echo "%s" > %s' % (what, filename))
-        
+
     def _compareFiles(self, runner, file1, file2):
         Util.printStep('Comparing %s and %s content...' % (file1, file2))
         self._loginViaSsh(runner, 'diff %s %s' % (file1, file2))
 
-    def _compareLocalFiles(self, file1, file2):
-        Util.printStep('Comparing %s and %s content...' % (file1, file2))
-        return Util.execute(['diff', file1, file2])
-        
     def _modeprobe(self, runner, module):
         Util.printStep('Loading module %s...' % module)
         self._loginViaSsh(runner, 'modprobe %s' % module)
-        
+
+    def _compareLocalFiles(self, file1, file2):
+        Util.printStep('Comparing %s and %s content...' % (file1, file2))
+        return Util.execute(['diff', file1, file2])
+
     def _gunzip(self, filename):
         Util.printStep("Unzipping file %s..." % filename)
         rc, output = Util.execute(['/bin/gunzip', filename], withOutput=True)
