@@ -22,8 +22,11 @@ import re
 import shutil
 import time
 import tempfile
+import xml.etree.ElementTree as ET
 from datetime import datetime
 
+import requests
+
 from stratuslab import Exceptions
 from stratuslab import Defaults
 from stratuslab.Util import appendOrReplaceInFile, execute, fileAppendContent, \
@@ -33,10 +36,13 @@ from stratuslab.system.PackageInfo import PackageInfo
 from stratuslab.system import Systems
 from stratuslab.Exceptions import ExecutionException
 
+
 class BaseSystem(object):
 
     os = ''
     caRepoName = 'CAs'
+    voIdCardUrl = 'http://operations-portal.egi.eu/xml/voIDCard/public/all/true'
+    vomsesDir = '/etc/grid-security/vomsdir'
 
     def __init__(self):
         dateNow = datetime.now().strftime('%Y-%m-%d-%H-%M-%S')
@@ -46,6 +52,7 @@ class BaseSystem(object):
 
         self.extraRepos = {}
         self.packages = {}
+        self.packages.update({'opennebula' : PackageInfo('one-3.2-StratusLab')})
         self.installPackagesErrorMsgs = []
         self.repoFileNamePattern = '/etc/%s'
         self.certificateAuthorityPackages = ''
@@ -209,14 +216,20 @@ class BaseSystem(object):
                         self.oneGroup])
 
     def createCloudAdmin(self):
+        # see below...
+        # self.createDirsCmd(os.path.dirname(self.oneHome))
 
-        self.createDirsCmd(os.path.dirname(self.oneHome))
-
-        self.executeCmd(['useradd', '-d', self.oneHome, '-g',
+        self.executeCmd(['useradd', '-g',
                         self.oneGroup, '-u', self.oneUid, self.oneUsername,
                         '-s', '/bin/bash', '-p', self.onePassword, '--create-home',
                         '--expiredate ""', '--inactive -1'])
 
+        # hack to reset the value of self.oneHome
+        # the code assumes that the account exists before initializing this class
+        # this is not the case as it is created by installing the one package
+        self.oneHome = None
+        self._setOneHome()
+
     # -------------------------------------------
     #     ONE admin env config and related
     # -------------------------------------------
@@ -295,6 +308,12 @@ class BaseSystem(object):
         self.chmodCmd(confFile, 0600)
 
     def configureCloudAdminAccount(self):
+        # hack to reset the value of self.oneHome
+        # the code assumes that the account exists before initializing this class
+        # this is not the case as it is created by installing the one package
+        self.oneHome = None
+        self._setOneHome()
+
         oneAuthFile = '%s/.one/one_auth' % self.oneHome
         self.appendOrReplaceInFileCmd(oneAuthFile,
                                       self.oneUsername, '%s:%s' % (self.oneUsername, self.onePassword))
@@ -865,6 +884,7 @@ class BaseSystem(object):
             self._installCAs()
             self._installFetchCrl()
             self._enableFetchCrl()
+            self._installVomsFiles()
 
     def _enableFetchCrl(self):
         pass
@@ -889,12 +909,53 @@ class BaseSystem(object):
             if not self.isPackageInstalled(package):
                 Util.printError('Failed to install %s.' % package)
 
+    def installOpenNebula(self):
+        Util.printDetail('Installing OpenNebula')
+        self.installPackages([self.getPackageName('opennebula')])
+
     def _installFetchCrl(self):
         package = self.getPackageName('fetch-crl')
         self.installPackages([package])
         if not self.isPackageInstalled(package):
             Util.printError('Failed to install %s.' % package)
 
+    def _installVomsFiles(self):
+
+        r = requests.get(self.voIdCardUrl)
+        if r.status_code == requests.codes.ok:
+            if not os.path.exists(self.vomsesDir):
+                try:
+                    os.mkdir(self.vomsesDir)
+                except Exception as e:
+                    Util.printError('could not create ' + vomsesDir)
+
+            vo_data = ET.fromstring(r.text)
+
+            for idcard in vo_data:
+                voname = idcard.attrib['Name']
+                vopath = os.path.join(self.vomsesDir, voname)
+
+                if not os.path.exists(vopath):
+                    try:
+                        os.mkdir(vopath)
+                    except Exception as e:
+                        Util.printError('could not create ' + vopath)
+
+                for server in idcard.findall('./gLiteConf/VOMSServers/VOMS_Server'):
+                    hostname = server.find('hostname')
+                    dn = server.find('X509Cert/DN')
+                    ca_dn = server.find('X509Cert/CA_DN')
+                    if hostname is not None and dn is not None and ca_dn is not None:
+                        contents = '%s\n%s\n' % (dn.text, ca_dn.text)
+                        path = os.path.join(vopath, hostname.text + '.lsc')
+                        try:
+                            with open(path, 'w') as f:
+                                f.write(contents)
+                        except Exception as e:
+                            Util.printError('could not create file ' + path)
+        else:
+            Util.printError('error retrieving VO ID card data from ' + self.voIdCardUrl)
+
     # -------------------------------------------
     # DHCP server
     # -------------------------------------------
